package com.caimei.service.auth.impl;

import com.caimei.config.FastDfsClient;
import com.caimei.mapper.cmMapper.AuthMapper;
import com.caimei.mapper.cmMapper.AuthProductMapper;
import com.caimei.mapper.ldmMapper.LdmMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.*;
import com.caimei.model.vo.*;
import com.caimei.service.auth.AuthProductService;
import com.caimei.service.auth.AuthService;
import com.caimei.service.auth.ShopService;
import com.caimei.service.auth.UploadService;
import com.caimei.utils.Base64Util;
import com.caimei.utils.ImageUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import javax.swing.*;
import java.awt.*;
import java.awt.Font;
import java.io.*;
import java.math.BigDecimal;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Slf4j
@Service
public class AuthServiceImpl implements AuthService {

    @Resource
    private AuthMapper authMapper;

    @Resource
    private LdmMapper ldmMapper;

    @Value("${caimei.zpapi}")
    private String zpServer;

    private AuthProductService authProductService;

    @Autowired
    public void setAuthProductService(AuthProductService authProductService) {
        this.authProductService = authProductService;
    }

    private ShopService shopService;

    @Autowired
    public void setShopService(ShopService shopService) {
        this.shopService = shopService;
    }

    private UploadService uploadService;

    @Autowired
    public void setUploadService(UploadService uploadService) {
        this.uploadService = uploadService;
    }

    @Value("${spring.profiles.active}")
    private String active;

    @Autowired
    private FastDfsClient client;

    @Value("${caimei.imageDomain}")
    private String imageDomain;

    @Override
    public ResponseJson<PageInfo<AuthVo>> getAuthList(Integer listType, Integer authUserId, String authParty,
                                                      String mobile, Integer status, Integer starFlag, Integer auditStatus,
                                                      Integer lowerAuditStatus, Integer shopAuditStatus, Integer sendStatus, Integer pageNum, Integer pageSize) {
        listType = null == listType ? 1 : listType;
        PageHelper.startPage(pageNum, pageSize);
        List<AuthVo> authList = authMapper.getAuthList(listType, authUserId, authParty, mobile, status, starFlag, auditStatus, lowerAuditStatus, shopAuditStatus, sendStatus);
        PageInfo<AuthVo> pageData = new PageInfo<>(authList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson updateAuthStatus(Integer authId, Integer status) {
        if (null == authId) {
            return ResponseJson.error("请输入授权id");
        }
        if (null == status) {
            return ResponseJson.error("请输入要更新的状态值");
        }
        authMapper.updateAuthStatusByAuthId(authId, status);
        if (0 == status) {
            return ResponseJson.success("下线品牌授权成功");
        } else {
            return ResponseJson.success("上线品牌授权成功");
        }
    }

    @Override
    public ResponseJson deleteAuth(Integer authId) {
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入授权id");
        }
        // 删除品牌授权
        authMapper.deleteAuthByAuthId(authId);
        // 删除轮播图
        authMapper.deleteBanner(authId);
        // 删除商品及商品参数
        List<Integer> productIdList = authProductService.getProductIdsByAuthId(authId);
        productIdList.forEach(productId->{
            if (null != productId) {
                authProductService.deleteProduct(productId);
            }
        });
        return ResponseJson.success("删除品牌授权成功");
    }

    @Override
    public ResponseJson<AuthFormVo> getAuthFormData(Integer authId) {
        if (null == authId) {
            return ResponseJson.error("参数异常,机构id不能为空", null);
        }
        AuthFormVo authFormVo = authMapper.getAuthFormById(authId);
        if (null != authFormVo.getLng()) {
            authFormVo.setLngAndLat(authFormVo.getLng() + "," + authFormVo.getLat());
        }
        List<String> bannerList = authMapper.getBannerList(authId);
        authFormVo.setBannerList(bannerList);
        return ResponseJson.success(authFormVo);
    }

    @Override
    public ResponseJson<List<AuthVo>> getAuthSelectList(Integer authUserId) {
        List<AuthVo> authList = authMapper.getAuthList(1, authUserId, null, null, null, null, null, null, null, null);
        return ResponseJson.success(authList);
    }

    @Override
    public ResponseJson importLdmImage(Integer authUserId) {
        List<LdmDataPo> ldmClubData = ldmMapper.getLdmClubData(null, 0);
        ldmClubData.forEach(ldmClub->{
            String pic2 = ldmClub.getPic2();
            String pic3 = ldmClub.getPic3();
            String pic4 = ldmClub.getPic4();
            List<AuthVo> authList = authMapper.getAuthByNameAndAddress(ldmClub.getAuthParty(), ldmClub.getAddress());
            if (null != authList && authList.size() > 0 ) {
                if (authList.size() > 1) {
                    log.info(">>>>>>>>>>>>>>>>>>>>>导入ldm门店图错误：对应门店过多，门店名称：" + ldmClub.getAuthParty());
                } else {
                    AuthVo auth = authList.get(0);
                    Integer authId = auth.getAuthId();
                    if (StringUtils.isNotEmpty(pic2) || StringUtils.isNotEmpty(pic3) || StringUtils.isNotEmpty(pic4)) {
                        authMapper.deleteBanner(authId);
                        insertBanner(pic2, authId);
                        insertBanner(pic3, authId);
                        insertBanner(pic4, authId);
                    }
                    if (StringUtils.isNotEmpty(ldmClub.getRemarks())) {
                        authMapper.updateRemarks(authId, ldmClub.getRemarks());
                    }
                }
            } else {
                log.info(">>>>>>>>>>>>>>>>>>>>>导入ldm门店图错误：找不到对应门店，门店名称：" + ldmClub.getAuthParty());
            }
        });
        return ResponseJson.success();
    }

    @Override
    public ResponseJson checkAuth(Integer authId) {
        authMapper.checkAuth(authId);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson starAuth(Integer authId, Integer starFlag) {
        authMapper.starAuth(authId, starFlag);
        return ResponseJson.success();
    }

    private void insertBanner(String pic, Integer authId) {
        if (StringUtils.isNotEmpty(pic)) {
            String imagePath = "https://wangdian.skinovachina.com" + pic;
            String fileName = imagePath.substring(imagePath.lastIndexOf("/") + 1);
            try {
                String banner = uploadService.saveFileByUrl(imagePath, fileName);
                authMapper.insertBanner(authId, banner);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @Override
    public ResponseJson saveAuth(CmBrandAuthPo auth, List<String> bannerList, boolean importFlag, Integer source) {
        Integer authId = auth.getId();
        boolean insertFlag = null == authId;
        AuthVo dbAuth = null;
        if (!insertFlag) {
            dbAuth = authMapper.getAuthById(authId);
        }
        String authParty = auth.getAuthParty();
        if (StringUtils.isBlank(authParty)) {
            return ResponseJson.error("参数异常，请输入授权机构名称");
        }
        if (null == auth.getFirstClubType()) {
            return ResponseJson.error("请勾选机构类型");
        }
        if ((1 == auth.getFirstClubType() || 2 == auth.getFirstClubType()) && null == auth.getSecondClubType()) {
            return ResponseJson.error("请勾选二级机构类型");
        }
        if (1 == auth.getFirstClubType() && StringUtils.isEmpty(auth.getMedicalLicenseImage())) {
            return ResponseJson.error("请上传医疗许可证");
        }
        if (null == auth.getEmpNum()) {
            return ResponseJson.error("请输入员工人数");
        }
        if (1 == source) {
            if (null == auth.getCreateBy()) {
                return ResponseJson.error("参数异常，请输入创建人id");
            }
            /*if (1 == auth.getAuthImageType() && StringUtils.isEmpty(auth.getAuthImageLogo())) {
                return ResponseJson.error("授权牌logo不能为空");
            }*/
            if (2 == auth.getAuthImageType() && StringUtils.isEmpty(auth.getAuthImage())) {
                return ResponseJson.error("授权牌不能为空");
            }
        }else {
            // 机构添加默认模板库生成
            auth.setAuthImageType(1);
        }
        if (!importFlag) {
            if (null == auth.getProvinceId() || null == auth.getCityId() || null == auth.getTownId() || StringUtils.isEmpty(auth.getAddress()) || null == auth.getLng() || null == auth.getLat()) {
                return ResponseJson.error("参数异常，地址信息异常");
            }
            if (StringUtils.isEmpty(auth.getLogo())) {
                return ResponseJson.error("参数异常，请上传机构logo");
            }
            if (null == bannerList || bannerList.size() <= 0) {
                return ResponseJson.error("参数异常，请上传轮播图");
            }
        }
        // 供应商保存，直接上线；机构保存，需要供应商审核通过后才上线
        if (null != dbAuth && 1 != dbAuth.getAuditStatus()) {
            // 被驳回的数据，编辑变为待审核状态
            auth.setStatus(2);
            auth.setAuditStatus(2);
        } else {
            auth.setStatus(1 == source ? 1 : 2);
            auth.setAuditStatus(1 == source ? 1 : 2);
        }
        Integer adminUserId = authMapper.getAdminUserId();
        auth.setAuditBy(adminUserId);
        auth.setAuditTime(new Date());
        if (1 == source) {
            auth.setShopAuditBy(auth.getCreateBy());
            auth.setShopAuditTime(new Date());
        }
        auth.setDelFlag(0);
        auth.setCheckFlag(0);
        auth.setShopAuditStatus(1 == source ? 1 : 2);
        /*
            保存授权
         */
        if (insertFlag) {
            authMapper.insertAuth(auth);
        } else {
            authMapper.updateAuthByAuthId(auth);
            // 删除原有的轮播图
            authMapper.deleteBanner(auth.getId());
        }
        // 保存之后生成授权牌和水印授权牌
        String authImage = null;
        if (1 == auth.getAuthImageType()) {
            // 模板库生成
            // 获取对应模板
            TemplateVo authTemplate = authMapper.getAuthTemplate(auth.getId(), null, 1);
            authImage = generateAuthImage(authTemplate, auth);
            auth.setAuthImage(authImage);
        }
        // 添加水印
        if (StringUtils.isNotEmpty(auth.getAuthImage())) {
            auth.setPcAuthImage(addWaterMark(auth.getAuthImage(), 1));
            auth.setAppletsAuthImage(addWaterMark(auth.getAuthImage(), 2));
            authMapper.updateAuthImage(auth);
        }
        // 保存轮播图
        if (null != bannerList) {
            bannerList.forEach(banner -> authMapper.insertBanner(auth.getId(), banner));
        }
        return ResponseJson.success("保存品牌授权成功", auth);
    }

    @Override
    public String addWaterMark(String image,Integer type){
        try {
            //type:1pc,2applets
            ClassPathResource classPathResource = new ClassPathResource("/images/newPcWaterMark.png");
            InputStream inputStreamImg = classPathResource.getInputStream();
            Image pcWaterMarkImg = ImageIO.read(inputStreamImg);
            classPathResource = new ClassPathResource("/images/newAppletsWaterMark.png");
            inputStreamImg = classPathResource.getInputStream();
            Image appletsWaterMarkImg = ImageIO.read(inputStreamImg);
            String img = ImageUtils.markImageByIcon(type == 1 ? pcWaterMarkImg : appletsWaterMarkImg, image, null);
            String imagePath = null;
            if (StringUtils.isNotEmpty(img)) {
                MultipartFile imgFile = Base64Util.base64ToMultipart(img);
                if (null != imgFile) {
                    imagePath = uploadService.saveFile(imgFile);
                }
                log.info(">>>>>>>>>>>>>>>>水印图片上传成功:" + imagePath);
            } else {
                log.info(">>>>>>>>>>>>>>>>水印图片上传失败");
            }
            return imagePath;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    @Override
    public String generateAuthImage(TemplateVo authTemplate, CmBrandAuthPo auth) {
        if (null != authTemplate) {
            // 根据模板id设置相关数据
            Map<String, Object> templateInfo = getTemplateInfo(authTemplate, auth);
            Object templateImage = templateInfo.get("templateImage");
            if (null != templateImage) {
                String authImage = ImageUtils.generateAuthImage(templateInfo);
                log.info("【图片上传】>>>>>>>>>>>>>>>>图片临时路径:" + authImage);
                // 临时图片
                File tempFile = new File(authImage);
                String imageUrl = null;
                try {
                    imageUrl = imageDomain + "/" + client.uploadFile(authImage);
                } catch (Exception e) {
                    e.printStackTrace();
                }
                // 删除临时图片
                boolean delete = tempFile.delete();
                log.info("【图片上传】>>>>>>>>>>>>>>>>删除临时图片:" + delete);
                return imageUrl;
            } else {
                return null;
            }
        }
        return null;
    }

    private Map<String,Object> getTemplateInfo(TemplateVo template, CmBrandAuthPo auth) {
        HashMap<String, Object> map = new HashMap<>();
        Integer templateId = template.getTemplateId();
        if (1 == templateId) {
            map.put("templateImage", template.getTemplateImage());
            double rate = 0.15;
            if (StringUtils.isNotEmpty(auth.getAuthImageLogo())) {
                // 获取授权牌logo位置
                try {
                    ImageIcon imageIcon = new ImageIcon(new URL(template.getTemplateImage()));
                    Image srcImg = imageIcon.getImage();
                    int srcWidth = srcImg.getWidth(null);
                    ImageIcon authImageLogo = new ImageIcon(new URL(auth.getAuthImageLogo()));
                    Image authLogo = authImageLogo.getImage();
                    int authLogoWidth = authLogo.getWidth(null);
                    int x = (srcWidth - (int) Math.round(238 * rate) - authLogoWidth) / 2 + (int) Math.round(238 * rate);
                    int y = (int) Math.round(1230 * rate);
                    map.put("addImage1_x", x);
                    map.put("addImage1_y", y);
                    map.put("addImage1_image", auth.getAuthImageLogo());
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
            // 添加认证编号信息
            if (StringUtils.isNotEmpty(auth.getAuthCode())) {
                map.put("addWord1_content", auth.getAuthCode());
                map.put("addWord1_color", "218,185,107");
                map.put("addWord1_type", "思源宋体");
                map.put("addWord1_style", Font.BOLD);
                map.put("addWord1_size", (int) Math.round(90 * rate));
                map.put("addWord1_x", (int) Math.round(2168 * rate));
                map.put("addWord1_y", (int) Math.round(3157 * rate));
            }
            // 添加认证日期信息
            if (null != auth.getAuthDate()) {
                SimpleDateFormat format = new SimpleDateFormat("yyyy.MM.dd");
                map.put("addWord2_content", format.format(auth.getAuthDate()));
                map.put("addWord2_color", "218,185,107");
                map.put("addWord2_type", "思源宋体");
                map.put("addWord2_style", Font.PLAIN);
                map.put("addWord2_size", (int) Math.round(90 * rate));
                map.put("addWord2_x", (int) Math.round(2085 * rate));
                map.put("addWord2_y", (int) Math.round(3289 * rate));
            }
            // 添加二维码信息
            if (StringUtils.isNotEmpty(template.getQrPosition())) {
                String qrCodeLink = zpServer + "/" + auth.getAuthUserId() + "/app/approve/club/detail?id=" + auth.getId();
                map.put("addQr1_link", qrCodeLink);
                map.put("addQr1_size", template.getQrSize());
                String[] split = template.getQrPosition().split(",");
                if (split.length == 2) {
                    map.put("addQr1_x", Integer.parseInt(split[0]));
                    map.put("addQr1_y", Integer.parseInt(split[1]));
                }
            }
        }
        return map;
    }

    @Override
    public ResponseJson auditAuth(Integer authId, Integer auditStatus, String invalidReason, Integer auditBy, Integer source) {
        if (authId == null) {
            return ResponseJson.error("请输入授权id");
        }
        if (auditStatus == null) {
            return ResponseJson.error("请输入审核结果");
        }
        if (auditStatus == 0 && StringUtils.isEmpty(invalidReason)) {
            return ResponseJson.error("请输入审核不通过的原因");
        }
        source = null == source ? 1 : source;
        Date auditTime = new Date();
        // 授权状态更新
        Integer status = null;

        if (auditStatus == 0) {
            // 审核不通过，下线授权
            status = 0;
        } else {
            // 审核通过，上线授权
            status = 1;
        }
        if (1 == source) {
            authMapper.updateAuthAuditStatus(authId, status, auditStatus, invalidReason, auditBy, auditTime);
        }
        if (2 == source) {
            authMapper.updateAuthShopAuditStatus(authId, status, auditStatus, invalidReason, auditBy, auditTime);
        }
        return ResponseJson.success("审核机构认证成功");
    }


    @Override
    @Transactional(rollbackFor=Exception.class)
    public ResponseJson importDataByExcel(MultipartFile file, Integer authUserId, Integer createBy) {
        String originalFilename = file.getOriginalFilename();
        String randomStr = UUID.randomUUID().toString();
        assert originalFilename != null;
        int index = originalFilename.lastIndexOf(".");
        String extName = originalFilename.substring(index);
        String filePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempFile/";
        if ("dev".equals(active)) {
            filePath = "D:\\WorkSpace\\file\\tempImport\\";
        }
        filePath += randomStr + extName;
        try {
            File tempFile = new File(filePath);
            if (!tempFile.exists()) {
                tempFile.mkdirs();
            }
            file.transferTo(tempFile);
            return saveExcelData(filePath, authUserId, createBy);
        } catch (IOException e) {
            e.printStackTrace();
        }
        log.info(">>>>>>>>>>>>>>>>文件临时路径:" + filePath);
        return null;
    }


    private ResponseJson saveExcelData(String filePath, Integer authUserId, Integer createBy) {
        //判断是否为excel类型文件
        if (!filePath.endsWith(".xls") && !filePath.endsWith(".xlsx")) {
            System.out.println("文件不是excel类型");
        }
        // 获取供应商品牌
        List<String> shopBrands = shopService.getShopBrands(authUserId);

        // 授权列表
        List<CmBrandAuthPo> authImportList = new ArrayList<>();

        try {
            FileInputStream fis = new FileInputStream(filePath);
            // 得到表格数据
            XSSFWorkbook workbook = new XSSFWorkbook(fis);

            //得到第一个工作表（机构表）
            XSSFSheet authPartySheet = workbook.getSheetAt(0);
            //获得表头
            Row rowHead = authPartySheet.getRow(0);
            //判断表头是否正确
            if (9 != rowHead.getLastCellNum() || !"机构名称".equals(rowHead.getCell(0).getStringCellValue())) {
                return ResponseJson.error("授权机构表格式错误");
            }
            // 获得数据的总行数
            int authPartyRowNum = authPartySheet.getLastRowNum();

            //获得所有数据
            for (int i = 1; i <= authPartyRowNum; i++) {
                //获得第i行对象
                Row authPartyRow = authPartySheet.getRow(i);
                if (null == authPartyRow) {
                    break;
                }
                Cell cell = null;
                // 校验机构名称
                cell = authPartyRow.getCell(0);
                cell.setCellType(CellType.STRING);
                String authParty = cell.getStringCellValue();
                if (StringUtils.isBlank(authParty)) {
                    return ResponseJson.error("第" + i + 1 + "行机构名称不能为空");
                }
                // 校验省市区
                cell = authPartyRow.getCell(1);
                cell.setCellType(CellType.STRING);
                String area = cell.getStringCellValue();
                if (StringUtils.isBlank(area)) {
                    return ResponseJson.error("第" + i + 1 + "行所在地区不能为空");
                }
                String[] areaSplit = area.split("/");
                if (areaSplit.length < 2 || areaSplit.length > 3) {
                    return ResponseJson.error("第" + i + 1 + "行所在地区格式错误");
                }
                // 省份
                String provinceName = areaSplit[0];
                if (StringUtils.isBlank(provinceName)) {
                    return ResponseJson.error("第" + i + 1 + "行省份不能为空");
                }
                if (provinceName.length() > 2) {
                    provinceName = provinceName.substring(0, provinceName.length() - 1).trim();
                }
                Integer provinceId = authMapper.getProvinceId(provinceName);
                // 市名
                String cityName = areaSplit[1];
                if (StringUtils.isBlank(cityName)) {
                    return ResponseJson.error("第" + i + 1 + "行市名不能为空");
                }
                if (cityName.length() > 2) {
                    cityName = cityName.substring(0, cityName.length() - 1).trim();
                }
                Integer cityId = authMapper.getCityId(cityName);
                Integer townId = null;
                if (areaSplit.length > 2) {
                    // 区名
                    String townName = areaSplit[2];
                    if (StringUtils.isNotEmpty(townName) && townName.length() > 2) {
                        townName = townName.substring(0, townName.length() - 1).trim();
                    }
                    List<TownPo> townList = authMapper.getTownList(townName);
                    for (int j = 0; j < townList.size(); j++) {
                        TownPo town = townList.get(j);
                        if (null == townId) {
                            if (null != cityId) {
                                if (town.getCityId().equals(cityId)) {
                                    townId = town.getTownId();
                                }
                            } else {
                                Integer checkCityId = authMapper.getCityIdByTownId(town.getTownId());
                                if (null != provinceId && null != checkCityId) {
                                    Integer checkProvinceId = authMapper.getProvinceIdByCityId(cityId);
                                    if (provinceId.equals(checkProvinceId)) {
                                        cityId = checkCityId;
                                        townId = town.getTownId();
                                    }
                                }
                            }
                        }
                    }
                }
                // 校验详细地址
                cell = authPartyRow.getCell(2);
                cell.setCellType(CellType.STRING);
                String address = cell.getStringCellValue();
                if (StringUtils.isBlank(address)) {
                    return ResponseJson.error("第" + i + 1 + "行详细地址不能为空");
                }
                // 校验经纬度
                cell = authPartyRow.getCell(3);
                cell.setCellType(CellType.STRING);
                String lngAndLat = cell.getStringCellValue();
                if (StringUtils.isBlank(lngAndLat)) {
                    return ResponseJson.error("第" + i + 1 + "行经纬度不能为空");
                }
                String[] split = lngAndLat.split(",");
                if (2 != split.length) {
                    return ResponseJson.error("第" + i + 1 + "行经纬度格式错误");
                }
                BigDecimal lng = new BigDecimal(split[0]);
                BigDecimal lat = new BigDecimal(split[1]);
                // 校验联系电话
                cell = authPartyRow.getCell(4);
                cell.setCellType(CellType.STRING);
                String mobile = cell.getStringCellValue();
                if (StringUtils.isBlank(mobile)) {
                    return ResponseJson.error("第" + i + 1 + "行联系电话不能为空");
                }
                // 认证编号
                cell = authPartyRow.getCell(5);
                cell.setCellType(CellType.STRING);
                String authCode = cell.getStringCellValue();
                // 认证日期
                Date authDate = null;
                cell = authPartyRow.getCell(6);
                cell.setCellType(CellType.STRING);
                String authDateStr = cell.getStringCellValue();
                if (StringUtils.isNotBlank(authDateStr)) {
                    SimpleDateFormat format = new SimpleDateFormat("yyyy.MM.dd");
                    authDate = format.parse(authDateStr);
                }
                // 校验员工人数
                Integer empNum = null;
                cell = authPartyRow.getCell(7);
                cell.setCellType(CellType.STRING);
                String empNumStr = cell.getStringCellValue();
                if (StringUtils.isBlank(empNumStr)) {
                    return ResponseJson.error("第" + i + 1 + "行员工人数不能为空");
                }
                try {
                    empNum = Integer.parseInt(empNumStr);
                } catch (Exception e) {
                    return ResponseJson.error("第" + i + 1 + "行员工人数格式错误");
                }
                // 校验店铺备注
                cell = authPartyRow.getCell(8);
                cell.setCellType(CellType.STRING);
                String remarks = cell.getStringCellValue();
                Integer customFlag = 0;
                if (StringUtils.isNotEmpty(remarks)) {
                    customFlag = 1;
                }
                CmBrandAuthPo authPo = new CmBrandAuthPo();
                authPo.setAuthParty(authParty);
                authPo.setProvinceId(provinceId);
                authPo.setCityId(cityId);
                authPo.setTownId(townId);
                authPo.setAddress(address);
                authPo.setLng(lng);
                authPo.setLat(lat);
                authPo.setMobile(mobile);
                authPo.setAuthCode(authCode);
                authPo.setAuthDate(authDate);
                authPo.setAuthImageType(1);
                authPo.setEmpNum(empNum);
                authPo.setCustomFlag(customFlag);
                authPo.setRemarks(remarks);
                authImportList.add(authPo);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseJson.error("导入失败,请检查表格数据");
        } finally {
            // 删除临时数据
            File tempFile = new File(filePath);
            boolean delete = tempFile.delete();
            log.info("【图片上传】>>>>>>>>>>>>>>>>删除临时表格:" + delete);
        }
        // 保存授权数据
        for (int i = 0; i < authImportList.size(); i++) {
            CmBrandAuthPo authPo = authImportList.get(i);
            // 保存授权机构
            authPo.setAuthUserId(authUserId);
            authPo.setCreateBy(createBy);
            authPo.setCreateSource(1);
            authPo.setFirstClubType(5);
            // 导入数据
            ResponseJson result = saveAuth(authPo, null, true, 1);
            if (result.getCode() != 0) {
                // 设置手动回滚事务
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return ResponseJson.error("导入失败");
            }
        }
        return ResponseJson.success("导入成功");
    }

}
